"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.keyDidBls12381g1g2 = exports.getBls12381g1g2VerificationMethod = void 0;
const crypto_1 = require("../../../../crypto");
const Key_1 = require("../../../../crypto/Key");
const bls12381g1_1 = require("./bls12381g1");
const bls12381g2_1 = require("./bls12381g2");
function getBls12381g1g2VerificationMethod(did, key) {
    const g1PublicKey = key.publicKey.slice(0, 48);
    const g2PublicKey = key.publicKey.slice(48);
    const bls12381g1Key = Key_1.Key.fromPublicKey(g1PublicKey, crypto_1.KeyType.Bls12381g1);
    const bls12381g2Key = Key_1.Key.fromPublicKey(g2PublicKey, crypto_1.KeyType.Bls12381g2);
    const bls12381g1VerificationMethod = (0, bls12381g1_1.getBls12381g1VerificationMethod)(did, bls12381g1Key);
    const bls12381g2VerificationMethod = (0, bls12381g2_1.getBls12381g2VerificationMethod)(did, bls12381g2Key);
    return [bls12381g1VerificationMethod, bls12381g2VerificationMethod];
}
exports.getBls12381g1g2VerificationMethod = getBls12381g1g2VerificationMethod;
exports.keyDidBls12381g1g2 = {
    supportedVerificationMethodTypes: [],
    getVerificationMethods: getBls12381g1g2VerificationMethod,
    getKeyFromVerificationMethod: () => {
        throw new Error('Not supported for bls12381g1g2 key');
    },
};
//# sourceMappingURL=bls12381g1g2.js.map